summaryrefslogtreecommitdiff
path: root/mpn/mips2/addmul_1.s
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
commit92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8 (patch)
treed19a83c2fa5195c6d7c22903719653db1020fd83 /mpn/mips2/addmul_1.s
parent119565df1ef96a64307d86f42b1925baecabb85d (diff)
downloadgmp-92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8.tar.gz
Change __mpn to __gmpn.
Diffstat (limited to 'mpn/mips2/addmul_1.s')
-rw-r--r--mpn/mips2/addmul_1.s10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpn/mips2/addmul_1.s b/mpn/mips2/addmul_1.s
index 6145771e3..8500e2d04 100644
--- a/mpn/mips2/addmul_1.s
+++ b/mpn/mips2/addmul_1.s
@@ -1,4 +1,4 @@
# MIPS __mpn_addmul_1 -- Multiply a limb vector with a single limb and
# add the product to a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 4
- .globl __mpn_addmul_1
- .ent __mpn_addmul_1
-__mpn_addmul_1:
+ .globl __gmpn_addmul_1
+ .ent __gmpn_addmul_1
+__gmpn_addmul_1:
.set noreorder
.set nomacro
@@ -94,4 +94,4 @@ $LC0: lw $10,0($4)
j $31
addu $2,$9,$2 # add high product limb and carry from addition
- .end __mpn_addmul_1
+ .end __gmpn_addmul_1
@@ -1,4 +1,4 @@
- # MIPS __mpn_addmul_1 -- Multiply a limb vector with a single limb and
+ # MIPS __gmpn_addmul_1 -- Multiply a limb vector with a single limb and
# add the product to a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.